#!/bin/bash

#
# this script reconfigures "our" packages
# it just needs the name as a parameter
# 

mypath="/var/lib/ctvdrcfg"
generic="/usr/share/ctvdrcfg"
myvars="/tmp/myvars.$$"
package=$1
installpath=`find $mypath -name "$package" -a -type d`

if [ "$installpath" = "" ]; then
    exit
fi

pushd $installpath > /dev/null

# be sure to stop running service (ipcop special)
# (ipcop image files will be loop mounted here!)
if [ -e "./pre_set1.sh" ]; then
    ./pre_set1.sh $MNTPT config
fi

# special for ipcop - need to mount root
# image to configure; it's just mountable now
# furthermore it needs to stop networking
# that fits in perfectly here
if [ -e "./pre_set2.sh" ]; then
    export MNTPT="/tmp/mountme.$$"
    mkdir $MNTPT
    ./pre_set2.sh $MNTPT config
fi

# get common vars (ip parameters, timestamp and the lot)
. $generic/getcommon.sh

# read current package's debconf variables into shell space
# they may overwrite common vars !
if [ -e "./vars" ]; then 
    $generic/read_and_export_debconf_vars.sh ./vars $myvars
    # get them exported
    . $myvars
fi

# let cfengine2 adapt config files as needed
if [ -e "./set.cfe2" ]; then
    cfagent -v -I -f ./set.cfe2 >> /tmp/cfoutput.log 2>&1
fi

# check if this package has some sub-options
# that need some values pushed in by cfengine2
subopts=`find . -type d -maxdepth 1 | grep -v "^.$" | sed 's|./||g'`
for s in $subopts; do
    subdirs=`find $s -type d | wc -l`
    # got one
    if [ ! -e "$s/.pkg" ] && [ "$subdirs" = "1" ]; then
        adddefaults="$s $adddefaults"
    fi
done

if [ "$adddefaults" != "" ]; then
    # get changed ones
    changed=`debconf-show ctvdrcfg | grep "^*" | grep -v "preseed" | \
cut -c 3- | cut -d ":" -f1`
fi

# do the same for any sub-option
for a in $adddefaults; do

    # do that only, if variables seen flag is set
    if echo "$changed" | grep -q "$a" ; then
	pushd $a > /dev/null
        # read current package's debconf variables into shell space
        # they may overwrite common vars !
	if [ -e "./vars" ]; then 
	    $generic/read_and_export_debconf_vars.sh ./vars $myvars
            # get them exported
	    . $myvars
	fi

        # let cfengine2 adapt config files as needed
	if [ -e "./set.cfe2" ]; then
	    cfagent -v -I -f ./set.cfe2 >> /tmp/cfoutput.log 2>&1
	fi
	popd > /dev/null
    fi
done

# unloopmount (ipcop special, restart is 
# done later with initcall) 
if [ -e "./pre_set2.sh" ]; then
    umount $MNTPT
fi

# some may have to be restarted now
if [ -e "./initcall.sh" ]; then
    ./initcall.sh config
fi

# clean up
rm -f $myvars
[ -d "$MNTPT" ] && rmdir $MNTPT
